#
# spec file for package saptune
#
# Copyright (c) 2017-2020 SUSE LLC.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           saptune
Version:        2.0.3
Release:        8.11.1
License:        GPL-3.0
Summary:        Comprehensive system tuning management for SAP solutions
Url:            https://www.suse.com/products/sles-for-sap
Group:          System/Management
Source0:        %{name}-%{version}.tgz
Source1:        rpmlintrc
Source2:        %{name}-1.1.9.tgz
BuildRequires:  go tuned bash-completion
Requires:       tuned vim
%if 0%{?sle_version} == 120100
Requires:       sapinit-systemd-compat
%endif
%if 0%{?sle_version} >= 150000
Requires:       systemd >= 234-24.42
%else
Requires:       systemd >= 228-142.1
%endif
Requires:       /usr/bin/cpupower
Requires:       sysstat
Requires:       uuidd
ExclusiveArch:  x86_64 ppc64le
%{?systemd_requires}

%define GONS github.com/SUSE
%define SRCDIR   src/%{GONS}/%{name}

%description
The utility adjusts system parameters such as kernel parameters and resource
limits to allow running various SAP solutions at satisfactory performance.
The utility can be used in place of sapconf.

%prep
mkdir -p %{SRCDIR}_v2
cd %{SRCDIR}_v2
tar xf %{S:0}
cd %{_builddir}
mkdir -p %{SRCDIR}_v1
cd %{SRCDIR}_v1
tar xf %{S:2}

%build
export GOPATH=$(pwd)
ln -s %{_builddir}/%{SRCDIR}_v1 %{SRCDIR}
cd %{SRCDIR}
gzip ospackage/man/saptune_v1.8
go build -o saptune_v1
cd %{_builddir}
rm %{SRCDIR}
mv %{SRCDIR}_v2 %{SRCDIR}
cd %{SRCDIR}
gzip ospackage/man/saptune.8
gzip ospackage/man/saptune_v2.8
gzip ospackage/man/saptune-note.5
gzip ospackage/man/saptune-migrate.7
gzip ospackage/%{_datadir}/doc/packages/%{name}/sapconf2saptune.1
go build

%install
cd %{SRCDIR}
mkdir -p %{buildroot}/%{_sbindir}
install -m 0755 %{name} %{buildroot}/%{_sbindir}/
install -m 0755 ../%{name}_v1/%{name}_v1 %{buildroot}/%{_sbindir}/%{name}_v1

# Sysconfig file
mkdir -p %{buildroot}/%{_fillupdir}
install -m 0644 ospackage/etc/sysconfig/%{name} %{buildroot}/%{_fillupdir}/sysconfig.%{name}

# scripts location
mkdir -p %{buildroot}/%{_datadir}/%{name}/scripts
pushd ospackage/%{_datadir}/%{name}/scripts
for scriptfiles in *; do
    install -m 0755 $scriptfiles %{buildroot}/%{_datadir}/%{name}/scripts
done
popd

# note files location
mkdir -p %{buildroot}/%{_datadir}/%{name}/notes
pushd ospackage/%{_datadir}/%{name}/notes
for notefiles in *; do
    case $notefiles in
    1984787|2205917|1557506)
        # SLE12 notes
        %if 0%{?sle_version} < 150000
            install -m 0644 $notefiles %{buildroot}/%{_datadir}/%{name}/notes/
        %endif
        ;;
    2578899|2684254)
        # SLE15 notes
        %if 0%{?sle_version} >= 150000
            install -m 0644 $notefiles %{buildroot}/%{_datadir}/%{name}/notes/
        %endif
        ;;
    *)
        install -m 0644 $notefiles %{buildroot}/%{_datadir}/%{name}/notes/
        ;;
    esac
done
popd

# NoteTemplate file
install -m 0644 ospackage/%{_datadir}/%{name}/NoteTemplate.conf %{buildroot}/%{_datadir}/%{name}/NoteTemplate.conf

# solution definition
install -m 0644 ospackage/%{_datadir}/%{name}/solsdeprecated %{buildroot}/%{_datadir}/%{name}/solsdeprecated
%if 0%{?sle_version} < 150000
    install -m 0644 ospackage/%{_datadir}/%{name}/solutions %{buildroot}/%{_datadir}/%{name}/solutions
%else
    install -m 0644 ospackage/%{_datadir}/%{name}/solutions_15 %{buildroot}/%{_datadir}/%{name}/solutions
%endif

# vendor file location
mkdir -p %{buildroot}/%{_sysconfdir}/%{name}/extra

# override file location
mkdir -p %{buildroot}/%{_sysconfdir}/%{name}/override

# manual pages
mkdir -p %{buildroot}/%{_mandir}/man5
install -m 0644 ospackage/man/saptune-note.5.gz %{buildroot}/%{_mandir}/man5/
mkdir -p %{buildroot}/%{_mandir}/man7
install -m 0644 ospackage/man/saptune-migrate.7.gz %{buildroot}/%{_mandir}/man7/
mkdir -p %{buildroot}/%{_mandir}/man8
install -m 0644 ospackage/man/saptune.8.gz %{buildroot}/%{_mandir}/man8/
install -m 0644 ospackage/man/saptune_v2.8.gz %{buildroot}/%{_mandir}/man8/
install -m 0644 ../%{name}_v1/ospackage/man/saptune_v1.8.gz %{buildroot}/%{_mandir}/man8/

# One tuned profile
mkdir -p %{buildroot}/%{_libexecdir}/tuned/%{name}
cp ospackage/profile/* %{buildroot}/%{_libexecdir}/tuned/%{name}/
ls -lR %{buildroot}/%{_libexecdir}/tuned/%{name}/

# bash-completion
mkdir -p %{buildroot}/%{_datadir}/bash-completion/completions
install -m 0644 ospackage/%{_datadir}/bash-completion/completions/%{name}.completion %{buildroot}%{_datadir}/bash-completion/completions/%{name}

# helper script for support
mkdir -p %{buildroot}/%{_datadir}/doc/packages/%{name}
install -m 0755 ospackage/%{_datadir}/doc/packages/%{name}/sapconf2saptune %{buildroot}/%{_datadir}/doc/packages/%{name}/sapconf2saptune
install -m 0644 ospackage/%{_datadir}/doc/packages/%{name}/sapconf2saptune.1.gz %{buildroot}/%{_datadir}/doc/packages/%{name}

%pre
if [ $1 -ne 1 ]; then
    # package update

    NOTEDIR=/usr/share/saptune/notes
    STATEDIR=/var/lib/saptune/saved_state
    if [ ! -d ${NOTEDIR} ]; then
        # installed package version is < 2.0, update v1 to v2
        # indicated by missing directory /usr/share/saptune/notes

        # only change version to '1' (compatibility), if saptune is really used
        # so check, if a solution or a note is defined
        if (grep '^TUNE_FOR_SOLUTIONS[[:space:]]*=[[:space:]]*""' /etc/sysconfig/saptune >/dev/null 2>&1) && (grep '^TUNE_FOR_NOTES[[:space:]]*=[[:space:]]*""' /etc/sysconfig/saptune >/dev/null 2>&1); then
            echo "saptune NOT configured and NOT used - version will be set to '2'"
        else
            echo "saptune configured and used - version will be set to '1'"
            touch /tmp/update_v1tov2_saptune_inst || :

            # preserve 'old' BOBJ and ASE note definition files for saptune
            # version 1 compatibility
            if [ -f /etc/saptune/extra/SAP_BOBJ-SAP_Business_OBJects.conf ]; then
                cp /etc/saptune/extra/SAP_BOBJ-SAP_Business_OBJects.conf /etc/saptune/extra/SAP_BOBJ_n2c.conf
            fi
            if [ -f /etc/saptune/extra/SAP_ASE-SAP_Adaptive_Server_Enterprise.conf ]; then
                cp /etc/saptune/extra/SAP_ASE-SAP_Adaptive_Server_Enterprise.conf /etc/saptune/extra/SAP_ASE_n2c.conf
            fi
        fi
    #else
        # package version 2.0 or later
    fi
#else
    # initial installation
fi

%post
%fillup_only -n saptune
# workaround for the missing directory.
mkdir -p /etc/security/limits.d

if [ $1 -ne 1 ]; then
    # package update
    if [ -f /tmp/update_v1tov2_saptune_inst ]; then
        # update from v1 to v2
        /usr/share/saptune/scripts/upd_helper v1tov2pi || :
    else
        # update from v2 to v2, call update helper script in posttrans
        touch /tmp/update_sle12tosel15_saptune_inst || :
        # clean up some leftover files from older saptune v2 versions
        /usr/share/saptune/scripts/upd_helper cleanup || :
    fi
#else
    # initial install
fi

%preun
test -n "$FIRST_ARG" || FIRST_ARG=$1
if [ $FIRST_ARG -eq 0 ]; then
    # Package removal, not upgrade
    # revert settings
    if (grep '^TUNE_FOR_SOLUTIONS[[:space:]]*=[[:space:]]*""' /etc/sysconfig/saptune >/dev/null 2>&1) && (grep '^TUNE_FOR_NOTES[[:space:]]*=[[:space:]]*""' /etc/sysconfig/saptune >/dev/null 2>&1); then
        # saptune note configured and not used - nothing to do
        :
    else
        # saptune configured and used - revert settings to clean up the system
        saptune daemon revert >/dev/null 2>&1 || :
    fi
    # clean up saved states left over
    rm -rf /var/lib/saptune/parameter/* /var/lib/saptune/saved_state/* || :
    # to suppress error messages from tuned, if the current active profile is
    # the removed saptune profile
    stvers=$(grep ^SAPTUNE_VERSION= /etc/sysconfig/saptune | awk -F '"' '{ print $2 }')
    (systemctl -q is-active tuned && [[ $(cat /etc/tuned/active_profile) == saptune ]] ) && ([[ "$stvers" == 1 ]] && tuned-adm off; /usr/sbin/saptune daemon stop >/dev/null 2>&1) || :
    # preserve 'old' BOBJ and ASE note definition files for saptune
    # version 1 compatibility
    if [ -f /etc/saptune/extra/SAP_BOBJ-SAP_Business_OBJects.conf ]; then
       echo "warning: /etc/saptune/extra/SAP_BOBJ-SAP_Business_OBJects.conf saved as /etc/saptune/extra/SAP_BOBJ-SAP_Business_OBJects.rpmsave"
        mv /etc/saptune/extra/SAP_BOBJ-SAP_Business_OBJects.conf /etc/saptune/extra/SAP_BOBJ-SAP_Business_OBJects.rpmsave || :
    fi
    if [ -f /etc/saptune/extra/SAP_ASE-SAP_Adaptive_Server_Enterprise.conf ]; then
	echo "warning: /etc/saptune/extra/SAP_ASE-SAP_Adaptive_Server_Enterprise.conf saved as /etc/saptune/extra/SAP_ASE-SAP_Adaptive_Server_Enterprise.conf.rpmsave"
        mv /etc/saptune/extra/SAP_ASE-SAP_Adaptive_Server_Enterprise.conf /etc/saptune/extra/SAP_ASE-SAP_Adaptive_Server_Enterprise.conf.rpmsave || :
    fi
    # preserve saptune configuration, if saptune was used
    # so check, if a solution or a note is defined
    if (grep '^TUNE_FOR_SOLUTIONS[[:space:]]*=[[:space:]]*""' /etc/sysconfig/saptune >/dev/null 2>&1) && (grep '^TUNE_FOR_NOTES[[:space:]]*=[[:space:]]*""' /etc/sysconfig/saptune >/dev/null 2>&1) && (grep '^NOTE_APPLY_ORDER[[:space:]]*=[[:space:]]*""' /etc/sysconfig/saptune >/dev/null 2>&1); then
       rm /etc/sysconfig/saptune || :
    else
       echo "warning: /etc/sysconfig/saptune saved as /etc/sysconfig/saptune.rpmsave"
       mv /etc/sysconfig/saptune /etc/sysconfig/saptune.rpmsave || :
    fi
fi

%posttrans -p /bin/bash
# Use a real bash script with an explicit "exit 0" at the end to be by default fail safe
# an explicit "exit 1" must be use to enforce package install/upgrade/erase failure where needed

if [ -f /tmp/update_v1tov2_saptune_inst ]; then
    # update from v1 to v2
    rm -f /tmp/update_v1tov2_saptune_inst || :

    # get back custom note definition files for BOBJ and/or ASE
    # needed for migration, if customer had applied these notes
    /usr/share/saptune/scripts/upd_helper v1tov2pt || :
fi
if [ -f /tmp/update_sle12tosel15_saptune_inst ]; then
    rm -f /tmp/update_sle12tosel15_saptune_inst || :
    # check for SAP Note name changes between SLE12 and SLE15
    /usr/share/saptune/scripts/upd_helper sle12to15pt || :
fi
exit 0

%files
%defattr(-,root,root)
%{_fillupdir}/sysconfig.%{name}
%{_sbindir}/%{name}
%{_sbindir}/%{name}_v1
%{_mandir}/man5/*
%{_mandir}/man7/*
%{_mandir}/man8/*
%dir %{_libexecdir}/tuned/%{name}
%{_libexecdir}/tuned/%{name}/*
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/extra
%dir %{_sysconfdir}/%{name}/override
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/notes
%dir %{_datadir}/%{name}/scripts
%{_datadir}/%{name}/notes/*
%{_datadir}/%{name}/scripts/*
%{_datadir}/%{name}/NoteTemplate.conf
%{_datadir}/%{name}/solutions
%{_datadir}/%{name}/solsdeprecated
%{_datadir}/bash-completion/completions/%{name}
%dir %{_datadir}/doc/packages/%{name}
%{_datadir}/doc/packages/%{name}/sapconf2saptune
%{_datadir}/doc/packages/%{name}/sapconf2saptune.1.gz
# Created at run-time by saptune executable
%ghost %dir %{_localstatedir}/lib/%{name}/
%ghost %dir %{_localstatedir}/lib/%{name}/parameter
%ghost %dir %{_localstatedir}/lib/%{name}/saved_state
%changelog
* Tue Feb 25 2020 abriel@suse.com
- update version of saptune v2 to 2.0.3
- changes to the UserTasksMax handling in saptune
  In SLE15 the limit is removed from the systemd login manager and
  therefore the setting is no longer supported in SLE15 by saptune.
  On a system running SLE12 we do not restart the logind service,
  but try to reload the new configuration after creating or
  removing the drop-in file for UserTasksMax by using
  'systemctl reload-or-try-restart systemd-logind'
  as display managers do not like a restart of the logind service.
  (bsc#1161791)
- add commands for listing enabled Notes/Solutions to saptune
  (bsc#1160564)
- correct typo in the year in the man page headline of man page
  saptune-note(5)
- SAP Note 1410736 updated to Version 6
  correct typo net.ipv4.tcp_probes to net.ipv4.tcp_keepalive_probes
* Tue Jan 14 2020 abriel@suse.com
- if a parameter is not supported by the system, the note action
  'verify' will no longer report this as an error even if the value
  is not compliant.
  Additionally if there is a non compliant 'grub' parameter, which
  has a compliant 'alternative' setting availabel (see man page
  saptune-note(5) for details), the note action 'verify' will no
  longer report this as an error
  (bsc#1159671)
* Thu Jan  2 2020 abriel@suse.com
- remove no longer needed and now misleading message at the end of
  note action 'revert'.
- check, if sapconf service is available before disabling this
  service during 'saptune daemon start'
  (bsc#1156049)
* Tue Dec  3 2019 abriel@suse.com
- add action 'delete' to the 'note' operation to delete a customer
  or vendor specific Note definition file including the
  corresponding override file if available.
  A confirmation is needed to finish the action.
  add action 'rename' to the 'note' operation to rename a customer
  or vendor specific Note definition file to a new name. If a
  corresponding override file is available, this file will be
  renamed too. A confirmation is needed to finish the action.
  If the Note is already applied, the action will be terminated
  with the information, that the Note first needs to be reverted
  before it can be deleted or renamed.
  (jsc#SLE-9283)
* Fri Nov  8 2019 abriel@suse.com
- Inform the customer that - by intention - the command
    'saptune note customise <NoteID>'
  does not apply changes immediately. It just changes the
  configuration in the 'override' file. These changes have to be
  applied in a second step.
  This is explained in the man page saptune_v2(8) and a message is
  printed in the logs and on the screen to inform the customer.
  (bsc#1142467)
* Thu Nov  7 2019 abriel@suse.com
- Add warning to man page, not to rename/remove/modify active
  configurations
  (bsc#1149002)
* Mon Oct 28 2019 abriel@suse.com
- update version of saptune v2 to 2.0.2
- support multi-queue I/O scheduler for block devices
  (bsc#1152598)
* Fri Oct  4 2019 abriel@suse.com
- check, if the directory /etc/security/limits.d exists before
  writing the limits drop-in file. If not, create it.
- add the '--no-pager' option to 'systemctl --list-unit-files' to
  get all services at once.
- add missing search pattern to the update helper script to find all
  old and superfluous notes during upgrade from SLE12 to SLE15
  For the daemon operations do not exit with an error, if a note
  definition file does not exist. Instead only log and print an
  error message, but continue with applying the other notes
  (bsc#1142526)
* Fri Jul 19 2019 abriel@suse.com
- on 12SP1 and 12SP2 the directory /etc/security/limits.d may not
  exist. So create the missing directory during postinstall of the
  package.
* Mon Jun 17 2019 abriel@suse.com
- update version of saptune v2 to 2.0.1
- update version of saptune v1 to 1.1.9 for migration purposes
- resetting all values to clean the system during package removal
- bugfixing saptune version 1:
  fix saptune issues with /etc/security/limits.conf (bsc#1124485)
  add deprecated message to the description of some notes
  set scheduler for note SUSE-GUIDE-01 correctly (bsc#1123808)
  No additional improvements or upgrades planned for saptune v1
  For new features or current SAP Note settings please migrate to
  saptune v2.
- support migration from saptune v1 to saptune v2
  ship both versions of saptune in one package to support a
  smooth migration controlled by the customer.
  see man saptune-migrate(5) for more information
- support note name changes and note deletion during update of
  saptune v2 from SLE12 to SLE15
- support different SAP Note definitions and solution definitions
  related to the used operation system version
  (distinguish between SLE12 and SLE15 at the moment)
- Remove calculation of optimized values, only set the values from
  the configuration file irrespective of the current system value.
  Current system value can be increase or decrease.
  ATTENTION: saptune no longer respects higher system values.
  Use the override option to change the values of the Note
  definition files, if needed
  (bsc#1124488)
- mark the Notes SUSE-GUIDE-01 and SUSE-GUIDE-02 as deprecated in
  saptune v1 and remove these Note definitions from saptune v2
  (bsc#1116799)
- add support helper script sapconf2saptune and the man page
- add new man pages saptune_v1.8, saptune_v2.8, saptune-note.5
  and saptune-migrate.7
  rewrite man page saptune.8
- add bash-completion for saptune
- add action 'show' to the 'note' operation to print content of
  the note definition file to stdout
- add new action 'create' to support the customer/vendor while
  creating a vendor or customer specific file in /etc/saptune/extra
  using the template file /usr/share/saptune/NoteTemplate.conf
- simplify file name syntax for the vendor files available in
  /etc/saptune/extra. Old file names still valid and supported.
  Add header support (version, date, description) for the vendor
  files available in /etc/saptune/extra as already available for
  the note definition files in /usr/share/saptune/notes
- no longer write or remove entries from /etc/security/limits.conf.
  Instead add or remove drop-in files in /etc/security/limits.d
  The filename syntax for the drop-in files /etc/security/limits.d
  is saptune-<domain>-<item>-<type>.conf
  The limits entry syntax inside the Note definition files changed
  to support more than one limits settings in the definition file
  (bsc#1128322)
- preserve comment sections of the security limits file
  /etc/security/limits.conf. Especially, if this is the only
  content of the file.
  (bsc#1124485)
- work with the current Note definition file to define the pagecache
  settings and not with the default file
  rename PAGECACHE_LIMIT_IGNORE_DIRTY to the correct sysctl name
  vm.pagecache_limit_ignore_dirty
  (bsc#1126220)
- setting of UserTaskMax is not done in the postinstall of the
  package. It's now done by applying the related SAP Notes.
  (bsc#1124489)
- starting to support severities INFO, WARNING, ERROR and DEBUG
  for the logging and add a defined format for the log messages
- remove saptune as active tuned profile during action
  'saptune daemon stop'
- start/stop services, if requested by SAP Notes, but do not
  enable/disable these services
  (bsc#1128325)
- adapt the parameter oriented save state file handling (store and
  revert) to the special needs of the security limits parameter
  (bsc#1124485)
- disable parameter settings using an override file (bsc#1124486)
- store the order of the note as they are applied to get the same
  system tuning result after a system reboot as before
- correct the revert of the vm.dirty parameters by handling their
  counterpart parameters in addition.
  (bsc#1124487)
- adjust operation customize to the new configuration files and
  override location and enable customize option for vendor and
  customer specific files in /etc/saptune/extra
  (bsc#1124487)
- Change output format of the operations list, verify and simulate
  (bsc#1124487)
- Display footnotes during 'verify' and 'simulate'
  (bsc#1124487)
- print current applied note order at the end of 'saptune note list'
  and 'saptune note verify'
- remove Netweaver formula for page cache calculation. Use the
  HANA approach '2%% system memory' for both
- display a warning message, if a [block] section is found in the
  Note definition file because on systems with a huge number of
  block devices this operation may take some time
- Add force_latency handling to 'cpu' section.
  Use the files in /sys/devices/system/cpu/cpu* instead of
  /dev/cpu_dma_latency.
  Remove the parameter from the tuned.conf file and add it to
  the SAP note files '1984787' and '2205917'
- Add action 'saptune revert all' and add parameter based saved
  state files to support proper revert functionality
  (bsc#1124487)
- Add override file handling for the solution definition using
  /etc/saptune/override/solution (bsc#1124486)
- Read solution definition from file /usr/share/saptune/solution
  instead of static coding inside of saptune.
  (bsc#1124486)
- tag deprecated solutions during list operation
- allow only ONE solution to be applied
- new solution definitions as discussed with SAP and Alliance team
- support solution names with '+'
- make sure a note, which is part of an applied solution definition,
  but was reverted manually later, will NOT applied again after a
  system reboot.
- One configuration file per SAP Note (bsc#1124486)
- add new SAP Notes and adapt content of SAP Notes
- Handle different locations of the new configuration files
  (/usr/share/saptune/note, /etc/saptune/extra)
  (bsc#1124486)
- Allow parameter override by the customer (bsc#1124486)
- Expand section handling of the 'ini file' handler to handle the
  new configuration file entries. Supported sections:
  version, reminder, login, mem, vm, block, limits, sysctl,
  pagecache, cpu, service, rpm, grub
  (bsc#1124486)
* Thu Jan  3 2019 abriel@suse.com
- remove new line from println arg list of main.go to support newer
  go versions.
  (bsc#1120741)
- update version to 1.1.8
* Thu Oct 25 2018 abriel@suse.com
- never ever stop or disable uuidd.socket in saptune (bsc#1100107)
- update version to 1.1.7
* Thu Apr 26 2018 abriel@suse.com
- correct content of /etc/systemd/logind.conf.d/sap.conf.
  (bsc#1089864)
- improve error messages and exclude special block devices
  from 'number of request' settings. Improve the verify option for
  the block devices.
  (bsc#1079599)
* Thu Feb  8 2018 gboiko@suse.com
- Fix a typo in package description. (bsc#1053374)
- Update from version 1.1.3 to 1.1.4
* Fri Dec 15 2017 abriel@suse.com
- Start to support multiqueue schedulers.
  Writing a message to the log file, if a block device does not
  support the choosen scheduler.
  (bsc#1072562)
* Wed Dec 13 2017 abriel@suse.com
- Check, if pagecache limit is available at the system. If yes, add
  SAP note 1557506 to the note list and the solution definition of
  saptune. If not, skip SAP note 1557506 silently
  (bsc#1071539, fate#323778)
* Mon Dec 11 2017 abriel@suse.com
- Skip using tuned-adm command inside of saptune. Instead write
  'saptune' profile directly to /etc/tuned/active_profile and
  enable and start the tuned service
  Remove the workaround for the tuned problem with section [cpu]
  (bsc#1060514)
* Fri Nov 10 2017 abriel@suse.com
- workaround for a tuned problem with section [cpu]
  (bsc#1060514)
* Wed Oct 25 2017 abriel@suse.com
- support customer entries in /etc/security/limits.conf containing
  values like 'unlimited' instead of an integer value.
  (bsc#1060469)
- change error handling and redirect error messages to stderr instead
  of stdout. (bsc#1050521)
* Fri Aug 11 2017 hguo@suse.com
- Fix a typo in package description.
  (bsc#1053374)
* Tue Jun 27 2017 abriel@suse.com
- Amend logind's behaviour
  (bsc#1031355, bsc#1039309, bsc#1043844)
* Fri May 12 2017 abriel@suse.com
- update man page to reflect the changes for bsc#1026172
* Thu Apr 27 2017 abriel@suse.com
- add solution SAP ASE (Sybase) and SAP Business OBJects (BOBJ)
  according to fate#320359.
* Fri Mar 24 2017 abriel@suse.com
- Support of vendor specific tune files located in /etc/saptune/extra
  (bsc#1026172).
* Mon Nov 14 2016 hguo@suse.com
- Tune a PowerPC little endian system in a way similar to x86 system.
  Bump version to 1.0.5 to fix (bsc#1009529).
* Fri Oct 21 2016 hguo@suse.com
- Fix processing of CLI parameter "--help" (bsc#1006114).
- Fix startup failure caused by absence of sapconf package (bsc#1006187).
* Tue Aug  2 2016 hguo@suse.com
- Avoid conflicting with sysconfig path of sapconf. (bsc#988186)
  Bump versin to 1.0.3.
* Fri Jul  8 2016 hguo@suse.com
- Remove conflict against sapconf to resolve
  bsc#988186.
  Bump version to 1.0.2.
* Mon Jul  4 2016 hguo@suse.com
- Exclusively build on X86_64 and PPC64le.
  Continue with fate#320360, fate#320361, fate#320362, fate#320633.
* Fri Jun  3 2016 hguo@suse.com
- Remove ExclusiveArch.
- Control uuidd as part of the tuning process.
- Minor changes in the wording of CLI program output.
- saptune conflicts with sapconf.
- Bump version to 1.0.1.
- fate#320360, fate#320361, fate#320362, fate#320633.
* Thu Apr 28 2016 hguo@suse.com
- First revision.
  Implement fate#320360, fate#320361, fate#320362, fate#320633.
